## Clarifai Model Upload Examples

A collection of pre-built triton models for different tasks.
To run inference locally using any of the examples here, you need to have the [Triton Inference Server](https://github.com/triton-inference-server/server/blob/main/docs/customization_guide/build.md#building-with-docker) installed.

Additionally some models may require other files such as checkpoints be downloaded before testing and/or deployment to Clarifai as they are ommitted here due to github file size limits.
See the Readme files under each model to see if there any additional files required and where to place them.
